@@ -245,7 +245,8 @@ exo_die_editor_class_init (ExoDieEditorClass *klass)
 
 
 static gboolean
-exo_die_true_if_application (const GValue *src_value,
+exo_die_true_if_application (GBinding     *binding,
+                             const GValue *src_value,
                              GValue       *dst_value,
                              gpointer      user_data)
 {
@@ -256,7 +257,8 @@ exo_die_true_if_application (const GValue *src_value,
 
 
 static gboolean
-exo_die_true_if_link (const GValue *src_value,
+exo_die_true_if_link (GBinding     *binding,
+                      const GValue *src_value,
                       GValue       *dst_value,
                       gpointer      user_data)
 {
@@ -300,7 +302,7 @@ exo_die_editor_init (ExoDieEditor *editor)
 
   editor->name_entry = gtk_entry_new ();
   gtk_entry_set_activates_default (GTK_ENTRY (editor->name_entry), TRUE);
-  exo_mutual_binding_new (G_OBJECT (editor), "name", G_OBJECT (editor->name_entry), "text");
+  g_object_bind_property (G_OBJECT (editor), "name", G_OBJECT (editor->name_entry), "text", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
   gtk_grid_attach (GTK_GRID (editor), editor->name_entry, 1, row, 1, 1);
   g_object_set (editor->name_entry, "hexpand", TRUE, NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), editor->name_entry);
@@ -317,7 +319,7 @@ exo_die_editor_init (ExoDieEditor *editor)
 
   entry = gtk_entry_new ();
   gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
-  exo_mutual_binding_new (G_OBJECT (editor), "comment", G_OBJECT (entry), "text");
+  g_object_bind_property (G_OBJECT (editor), "comment", G_OBJECT (entry), "text", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
   gtk_grid_attach (GTK_GRID (editor), entry, 1, row, 1, 1);
   g_object_set (entry, "hexpand", TRUE, NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
@@ -329,12 +331,18 @@ exo_die_editor_init (ExoDieEditor *editor)
   label = gtk_label_new_with_mnemonic (_("Comm_and:"));
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   g_object_set (label, "xalign", 1.0f, "yalign", 0.5f, NULL);
-  exo_binding_new_full (G_OBJECT (editor), "mode", G_OBJECT (label), "visible", exo_die_true_if_application, NULL, NULL);
+  g_object_bind_property_full (editor, "mode", label, "visible",
+                               G_BINDING_SYNC_CREATE,
+                               exo_die_true_if_application, NULL,
+                               NULL, NULL);
   gtk_grid_attach (GTK_GRID (editor), label, 0, row, 1, 1);
 
   entry = exo_die_command_entry_new ();
-  exo_mutual_binding_new (G_OBJECT (editor), "command", G_OBJECT (entry), "text");
-  exo_binding_new_full (G_OBJECT (editor), "mode", G_OBJECT (entry), "visible", exo_die_true_if_application, NULL, NULL);
+  g_object_bind_property (G_OBJECT (editor), "command", G_OBJECT (entry), "text", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
+  g_object_bind_property_full (editor, "mode", entry, "visible",
+                               G_BINDING_SYNC_CREATE,
+                               exo_die_true_if_application, NULL,
+                               NULL, NULL);
   gtk_grid_attach (GTK_GRID (editor), entry, 1, row, 1, 1);
   g_object_set (entry, "hexpand", TRUE, NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
@@ -345,13 +353,19 @@ exo_die_editor_init (ExoDieEditor *editor)
   label = gtk_label_new_with_mnemonic (_("_URL:"));
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   g_object_set (label, "xalign", 1.0f, "yalign", 0.5f, NULL);
-  exo_binding_new_full (G_OBJECT (editor), "mode", G_OBJECT (label), "visible", exo_die_true_if_link, NULL, NULL);
+  g_object_bind_property_full (editor, "mode", label, "visible",
+                               G_BINDING_SYNC_CREATE,
+                               exo_die_true_if_link, NULL,
+                               NULL, NULL);
   gtk_grid_attach (GTK_GRID (editor), label, 0, row, 1, 1);
 
   entry = gtk_entry_new ();
   gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
-  exo_mutual_binding_new (G_OBJECT (editor), "url", G_OBJECT (entry), "text");
-  exo_binding_new_full (G_OBJECT (editor), "mode", G_OBJECT (entry), "visible", exo_die_true_if_link, NULL, NULL);
+  g_object_bind_property (G_OBJECT (editor), "url", G_OBJECT (entry), "text", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
+  g_object_bind_property_full (editor, "mode", entry, "visible",
+                               G_BINDING_SYNC_CREATE,
+                               exo_die_true_if_link, NULL,
+                               NULL, NULL);
   gtk_grid_attach (GTK_GRID (editor), entry, 1, row, 1, 1);
   g_object_set (entry, "hexpand", TRUE, NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
@@ -362,17 +376,23 @@ exo_die_editor_init (ExoDieEditor *editor)
   label = gtk_label_new_with_mnemonic (_("Working _Directory:"));
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   g_object_set (label, "xalign", 1.0f, "yalign", 0.5f, NULL);
-  exo_binding_new_full (G_OBJECT (editor), "mode", G_OBJECT (label), "visible", exo_die_true_if_application, NULL, NULL);
+  g_object_bind_property_full (editor, "mode", label, "visible",
+                               G_BINDING_SYNC_CREATE,
+                               exo_die_true_if_application, NULL,
+                               NULL, NULL);
   gtk_grid_attach (GTK_GRID (editor), label, 0, row, 1, 1);
 
   box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
   gtk_grid_attach (GTK_GRID (editor), box, 1, row, 1, 1);
   g_object_set (box, "hexpand", TRUE, NULL);
-  exo_binding_new_full (G_OBJECT (editor), "mode", G_OBJECT (box), "visible", exo_die_true_if_application, NULL, NULL);
+  g_object_bind_property_full (editor, "mode", box, "visible",
+                               G_BINDING_SYNC_CREATE,
+                               exo_die_true_if_application, NULL,
+                               NULL, NULL);
 
   entry = gtk_entry_new ();
   gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
-  exo_mutual_binding_new (G_OBJECT (editor), "path", G_OBJECT (entry), "text");
+  g_object_bind_property (G_OBJECT (editor), "path", G_OBJECT (entry), "text", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
   gtk_box_pack_start (GTK_BOX (box), entry, TRUE, TRUE, 0);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
   gtk_widget_show (entry);
@@ -412,7 +432,10 @@ exo_die_editor_init (ExoDieEditor *editor)
   label = gtk_label_new (_("Options:"));
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   g_object_set (label, "xalign", 1.0f, "yalign", 0.5f, NULL);
-  exo_binding_new_full (G_OBJECT (editor), "mode", G_OBJECT (label), "visible", exo_die_true_if_application, NULL, NULL);
+  g_object_bind_property_full (editor, "mode", label, "visible",
+                               G_BINDING_SYNC_CREATE,
+                               exo_die_true_if_application, NULL,
+                               NULL, NULL);
   gtk_grid_attach (GTK_GRID (editor), label, 0, row, 1, 1);
 
   /* TRANSLATORS: Check button label in "Create Launcher" dialog, make sure to avoid mnemonic conflicts
@@ -422,8 +445,11 @@ exo_die_editor_init (ExoDieEditor *editor)
   gtk_widget_set_tooltip_text (button, _("Select this option to enable startup notification when the command "
                                          "is run from the file manager or the menu. Not every application supports "
                                          "startup notification."));
-  exo_mutual_binding_new (G_OBJECT (editor), "snotify", G_OBJECT (button), "active");
-  exo_binding_new_full (G_OBJECT (editor), "mode", G_OBJECT (button), "visible", exo_die_true_if_application, NULL, NULL);
+  g_object_bind_property (G_OBJECT (editor), "snotify", G_OBJECT (button), "active", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
+  g_object_bind_property_full (editor, "mode", button, "visible",
+                               G_BINDING_SYNC_CREATE,
+                               exo_die_true_if_application, NULL,
+                               NULL, NULL);
   gtk_grid_attach (GTK_GRID (editor), button, 1, row, 1, 1);
   g_object_set (button, "hexpand", TRUE, NULL);
 
@@ -434,8 +460,11 @@ exo_die_editor_init (ExoDieEditor *editor)
    */
   button = gtk_check_button_new_with_mnemonic (_("Run in _terminal"));
   gtk_widget_set_tooltip_text (button, _("Select this option to run the command in a terminal window."));
-  exo_mutual_binding_new (G_OBJECT (editor), "terminal", G_OBJECT (button), "active");
-  exo_binding_new_full (G_OBJECT (editor), "mode", G_OBJECT (button), "visible", exo_die_true_if_application, NULL, NULL);
+  g_object_bind_property (G_OBJECT (editor), "terminal", G_OBJECT (button), "active", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
+  g_object_bind_property_full (editor, "mode", button, "visible",
+                               G_BINDING_SYNC_CREATE,
+                               exo_die_true_if_application, NULL,
+                               NULL, NULL);
   gtk_grid_attach (GTK_GRID (editor), button, 1, row, 1, 1);
   g_object_set (button, "hexpand", TRUE, NULL);
 }
