@@ -33,7 +33,6 @@
 
 #include <gdk/gdkkeysyms.h>
 
-#include <exo/exo-binding.h>
 #include <exo/exo-cell-renderer-icon.h>
 #include <exo/exo-gtk-extensions.h>
 #include <exo/exo-icon-chooser-dialog.h>
@@ -43,6 +42,8 @@
 #include <exo/exo-private.h>
 #include <exo/exo-alias.h>
 
+#define FILTER_ENTRY_DELAY 300
+
 /**
  * SECTION: exo-icon-chooser-dialog
  * @title: ExoIconChooserDialog
@@ -74,8 +75,9 @@ static gboolean exo_icon_chooser_dialog_visible_func             (GtkTreeModel
 static gboolean exo_icon_chooser_dialog_start_interactive_search (ExoIconChooserDialog       *icon_chooser_dialog);
 static void     exo_icon_chooser_dialog_combo_changed            (GtkWidget                  *combo,
                                                                   ExoIconChooserDialog       *icon_chooser_dialog);
-static void     exo_icon_chooser_dialog_entry_changed            (GtkWidget                  *entry,
+static void     exo_icon_chooser_dialog_entry_changed_delay      (GtkEntry                   *entry,
                                                                   ExoIconChooserDialog       *icon_chooser_dialog);
+static gboolean exo_icon_chooser_dialog_entry_changed            (gpointer                    user_data);
 static void     exo_icon_chooser_dialog_entry_clear              (GtkEntry                   *entry,
                                                                   GtkEntryIconPosition        icon_pos,
                                                                   GdkEvent                   *event);
@@ -87,6 +89,7 @@ struct _ExoIconChooserDialogPrivate
 {
   GtkWidget *combo;
   GtkWidget *filter_entry;
+  guint      filter_entry_timeout_source_id;
   GtkWidget *icon_chooser;
   GtkWidget *file_chooser;
   gchar     *casefolded_text;
@@ -217,12 +220,13 @@ exo_icon_chooser_dialog_init (ExoIconChooserDialog *icon_chooser_dialog)
   g_object_set (label, "xalign", 0.0f, "yalign", 0.5f, NULL);
   gtk_grid_attach (GTK_GRID (table), label, 0, 1, 1, 1);
 
+  priv->filter_entry_timeout_source_id = 0;
   priv->filter_entry = gtk_entry_new ();
-  exo_binding_new (G_OBJECT (priv->filter_entry), "visible", G_OBJECT (label), "visible");
+  g_object_bind_property (G_OBJECT (priv->filter_entry), "visible", G_OBJECT (label), "visible", G_BINDING_SYNC_CREATE);
   gtk_grid_attach (GTK_GRID (table), priv->filter_entry, 1, 1, 1, 1);
   g_object_set (priv->filter_entry, "hexpand", TRUE, NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), priv->filter_entry);
-  g_signal_connect (G_OBJECT (priv->filter_entry), "changed", G_CALLBACK (exo_icon_chooser_dialog_entry_changed), icon_chooser_dialog);
+  g_signal_connect (G_OBJECT (priv->filter_entry), "changed", G_CALLBACK (exo_icon_chooser_dialog_entry_changed_delay), icon_chooser_dialog);
   gtk_entry_set_icon_from_icon_name (GTK_ENTRY (priv->filter_entry), GTK_ENTRY_ICON_SECONDARY, "edit-clear");
   gtk_entry_set_icon_tooltip_text (GTK_ENTRY (priv->filter_entry), GTK_ENTRY_ICON_SECONDARY, _("Clear search field"));
   gtk_entry_set_icon_sensitive (GTK_ENTRY (priv->filter_entry), GTK_ENTRY_ICON_SECONDARY, FALSE);
@@ -237,7 +241,7 @@ exo_icon_chooser_dialog_init (ExoIconChooserDialog *icon_chooser_dialog)
 
   /* setup the icon chooser (shown by default) */
   priv->icon_chooser = exo_icon_view_new ();
-  exo_binding_new (G_OBJECT (priv->icon_chooser), "visible", G_OBJECT (scrolled_window), "visible");
+  g_object_bind_property (G_OBJECT (priv->icon_chooser), "visible", G_OBJECT (scrolled_window), "visible", G_BINDING_SYNC_CREATE);
   g_signal_connect_swapped (priv->icon_chooser, "item-activated", G_CALLBACK (gtk_window_activate_default), icon_chooser_dialog);
   g_signal_connect_swapped (priv->icon_chooser, "selection-changed", G_CALLBACK (exo_icon_chooser_dialog_selection_changed), icon_chooser_dialog);
   g_signal_connect_swapped (priv->icon_chooser, "start-interactive-search", G_CALLBACK (exo_icon_chooser_dialog_start_interactive_search), icon_chooser_dialog);
@@ -293,6 +297,11 @@ exo_icon_chooser_dialog_finalize (GObject  *object)
 {
   ExoIconChooserDialogPrivate *priv = exo_icon_chooser_dialog_get_instance_private (EXO_ICON_CHOOSER_DIALOG (object));
 
+  if (priv->filter_entry_timeout_source_id != 0)
+    {
+      g_source_remove (priv->filter_entry_timeout_source_id);
+      priv->filter_entry_timeout_source_id = 0;
+    }
   g_free (priv->casefolded_text);
 
   (*G_OBJECT_CLASS (exo_icon_chooser_dialog_parent_class)->finalize) (object);
@@ -510,10 +519,29 @@ exo_icon_chooser_dialog_combo_changed (GtkWidget            *combo,
 
 
 static void
-exo_icon_chooser_dialog_entry_changed (GtkWidget            *combo,
-                                       ExoIconChooserDialog *icon_chooser_dialog)
+exo_icon_chooser_dialog_entry_changed_delay (GtkEntry             *entry,
+                                             ExoIconChooserDialog *icon_chooser_dialog)
 {
   ExoIconChooserDialogPrivate *priv = exo_icon_chooser_dialog_get_instance_private (icon_chooser_dialog);
+
+  if (priv->filter_entry_timeout_source_id != 0)
+    {
+      g_source_remove (priv->filter_entry_timeout_source_id);
+      priv->filter_entry_timeout_source_id = 0;
+    }
+
+  priv->filter_entry_timeout_source_id = g_timeout_add (FILTER_ENTRY_DELAY,
+                                                        exo_icon_chooser_dialog_entry_changed,
+                                                        icon_chooser_dialog);
+}
+
+
+
+static gboolean
+exo_icon_chooser_dialog_entry_changed (gpointer user_data)
+{
+  ExoIconChooserDialog        *icon_chooser_dialog = EXO_ICON_CHOOSER_DIALOG (user_data);
+  ExoIconChooserDialogPrivate *priv = exo_icon_chooser_dialog_get_instance_private (icon_chooser_dialog);
   const gchar                 *text;
   gchar                       *normalized;
   GtkTreeModel                *model;
@@ -537,6 +565,10 @@ exo_icon_chooser_dialog_entry_changed (GtkWidget            *combo,
   model = exo_icon_view_get_model (EXO_ICON_VIEW (priv->icon_chooser));
   if (G_LIKELY (model != NULL))
     gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (model));
+
+  priv->filter_entry_timeout_source_id = 0;
+
+  return FALSE;
 }
 
 
